import { Agile, Collection, Computed, defineConfig, removeProperties, runsOnServer, State, Storage, } from './internal';
let sharedAgileInstance = new Agile({
    key: 'shared',
    localStorage: !runsOnServer(),
});
export { sharedAgileInstance as shared };
export function assignSharedAgileInstance(agileInstance) {
    sharedAgileInstance = agileInstance;
}
export function createStorage(config) {
    return new Storage(config);
}
export function createState(initialValue, config = {}) {
    config = defineConfig(config, {
        agileInstance: sharedAgileInstance,
    });
    return new State(config.agileInstance, initialValue, removeProperties(config, ['agileInstance']));
}
export function createComputed(computeFunction, configOrDeps) {
    let _config = {};
    if (Array.isArray(configOrDeps)) {
        _config = defineConfig(_config, {
            computedDeps: configOrDeps,
        });
    }
    else {
        if (configOrDeps)
            _config = configOrDeps;
    }
    _config = defineConfig(_config, { agileInstance: sharedAgileInstance });
    return new Computed(_config.agileInstance, computeFunction, removeProperties(_config, ['agileInstance']));
}
export function createCollection(config, agileInstance = sharedAgileInstance) {
    return new Collection(agileInstance, config);
}
